/*
 * ******************************************************************************************
 * File		: ram.h
 * Author	: GowinSemicoductor
 * Chip		: AE350_SOC
 * Function	: RAM definitions.
 * ******************************************************************************************
 */

#ifndef __RAM_H__
#define __RAM_H__

// Includes ---------------------------------------------------------------------------------
#include "platform.h"


// Definitions ------------------------------------------------------------------------------

// Register definition
typedef struct
{
	__IO   unsigned int  DCMD;			/* Offset: 0x000 (port select) 	 [15:0] */
	__IO   unsigned int  DADDR;			/* Offset: 0x004 (write or read) [15:0] */
	__IO   unsigned int  DIN;			/* Offset: 0x008 (write only)    [15:0] */
	__I    unsigned int  DOUT;			/* Offset: 0x00C (ready only)    [15:0] */
} RAM_RegDef;


// RAM
#define RAM_BASE				AHB_EXT_BASE					// RAM address
#define AE350_RAM				((RAM_RegDef *) RAM_BASE )		// RAM register definition
#define DEV_RAM					AE350_RAM						// Device RAM

// Bit definitions
#define DATACMD		   			((unsigned int) 0x00000003)
#define DATAADDR	   			((unsigned int) 0x0000007F)
#define DATAIN				 	((unsigned int) 0x0000FFFF)
#define DATAOUT					((unsigned int) 0x0000FFFF)


// Declarations ----------------------------------------------------------------------------

void setDataCmd(RAM_RegDef* RAMx, unsigned int cmd);		// Set data command
unsigned int getDataCmd(RAM_RegDef* RAMx);					// Get data command

void setDataAddr(RAM_RegDef* RAMx, unsigned int addr);		// Set data address
unsigned int getDataAddr(RAM_RegDef* RAMx);					// Get data address

void setDataIn(RAM_RegDef* RAMx, unsigned int din);			// Set input data
unsigned int getDataIn(RAM_RegDef* RAMx);					// Get input data

unsigned int getDataOut(RAM_RegDef* RAMx);					// Get output data


#endif	/* __RAM_H__ */
